Channel

Enum Channel 

pub enum Channel {
    Stable(Stable),
    Beta(Beta),
    Nightly(Nightly),
}
A Rust release channel.

Does not include the once used Alpha release channel, which has not been used post 1.0.0.

Variants

See also: Stable, Beta and Nightly.

Reading materials

Variants



Stable(Stable)

The stable release channel



Beta(Beta)

The beta release channel



Nightly(Nightly)

The nightly release channel

Implementations

Source

impl Channel

pub fn stable(version: RustVersion) -> Self

Create a new Stable channel instance.

pub fn beta(version: RustVersion) -> Self

Create a new Beta channel instance.

pub fn nightly(date: Date) -> Self

Create a new Nightly channel instance.

pub fn is_stable(&self) -> bool

Whether the given Channel is of the Stable variant.

pub fn is_beta(&self) -> bool

Whether the given Channel is of the Beta variant.

pub fn is_nightly(&self) -> bool

Whether the given Channel is of the Nightly variant.

pub fn version(&self) -> Option<RustVersion>

Returns the release version, or None, if it’s a nightly release.

pub fn date(&self) -> Option<Date>

Returns the release date, or